@@ -57,6 +57,9 @@ from .chebi import *
 from . import ena
 from .ena import ENA
 
+from . import eva
+from .eva import *
+
 from . import ensembl
 from .ensembl import *
 
@@ -73,6 +76,12 @@ from .hgnc import *
 from . import intact
 from .intact import *
 
+from . import pubchem
+from .pubchem import *
+
+from . import pfam
+from .pfam import *
+
 from . import rhea
 from .rhea import *
 
@@ -88,6 +97,9 @@ from .omnipath import *
 from . import pdb
 from .pdb import *
 
+from . import pdbe
+from .pdbe import *
+
 from . import pride
 from .pride import *
 
@@ -110,8 +122,8 @@ from .quickgo import *
 from . import chembl
 from .chembl import *
 
-from . import picr
-from .picr import *
+#from . import picr
+#from .picr import *
 
 from . import psicquic
 from .psicquic import *
@@ -125,9 +137,6 @@ from .ncbiblast import *
 from . import biogrid
 from .biogrid import *
 
-from . import miriam
-from .miriam import *
-
 from . import arrayexpress
 from .arrayexpress import *
 
@@ -146,6 +155,12 @@ from .muscle import *
 from . import dbfetch
 from .dbfetch import *
 
+from . import bigg
+from .bigg import BiGG
+
+from . import omicsdi
+from .omicsdi import OmicsDI
+
 # sub packages inside bioservices.
 
 #import mapping
